"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const fs_1 = require("../fs");
/**
 * Recursively scans a directory, returning a map of stats keyed on the full path to the item.
 * @function scan
 * @memberof fsn/nextra
 * @param root The path to scan
 * @param options The options for the scan
 */
function scan(root, options = {}) {
    return scanDeep(path_1.resolve(root), new Map(), -1, options);
}
exports.default = scan;
const scanDeep = async (dir, results, level, options) => {
    const stats = await fs_1.lstat(dir);
    if (!options.filter || options.filter(stats, dir))
        results.set(dir, stats);
    if (stats.isDirectory() && (typeof options.depthLimit === 'undefined' || level < options.depthLimit)) {
        await Promise.all((await fs_1.readdir(dir)).map(part => scanDeep(path_1.join(dir, part), results, ++level, options)));
    }
    return results;
};
//# sourceMappingURL=scan.js.map